function [etopo_depth] = bepsii_etopo_depth(Nr,lat,lon)

%=========================================================================================================
%
% bepsii_etopo_depth : given the latitude & longitude of a series of ice cores, 
%                      find the corresponding water depth in the etopo database
%                      this is not super precise, but shit! can't do any
%                      different
%
% !!! you need the ETOPO bathymetry file !!!
% (netcdf format, ETOPO1_Bed_g_gmt4.grd.nc, ask me if you do not have it)
%
% IN
%
% Nr               : number of records found in the directory
% lat(Nr)          : latitude of all cores
% lon(Nr)          : longitude
%
% OUT
%
% etopo_depth(Nr)  : water depth at the closest point in the etopo data base
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Aug 2015, Lille)
%
%=========================================================================================================

disp ({' * bepsii_etopo_depth '})

% Find ETOPO depths for each core
ncid = netcdf.open('/Users/ioulianikolskaia/Boulot/IDL/BASE_FILES/ETOPO1/ETOPO1_Bed_g_gmt4.grd.nc');

lon_etopo_id = netcdf.inqVarID(ncid,'x');
lat_etopo_id = netcdf.inqVarID(ncid,'y');
z_etopo_id   = netcdf.inqVarID(ncid,'z');

lon_etopo    = netcdf.getVar(ncid,lon_etopo_id);
lat_etopo    = netcdf.getVar(ncid,lat_etopo_id);
z_etopo      = netcdf.getVar(ncid,z_etopo_id);

etopo_depth  = zeros(1,Nr);

for i=1:Nr
   i_etopo   = find( abs(lon_etopo-lon(i)) < 1.0e-2 );
   j_etopo   = find( abs(lat_etopo-lat(i)) < 1.0e-2 ) ; 
   etopo_depth(i) = z_etopo(i_etopo(1),j_etopo(1));
   if (etopo_depth(i) > 0 )
       etopo_depth(i) = -10;
   end
end