function [var_mm, var_mlo, var_mhi, N_mm] = bepsii_mm(Nr, var1d, month, i_type)

% you should add iqr in here
%=========================================================================================================
%
% bepsii_mm : computes monthly means of a 1D time series array
%
% IN
%
% Nr               : Number of records found in the directory
% var1d(1,Nr)      : Name of the variable to integrate
% month(1,Nr)      : Month
% i_type           : 1 for mean & +/- 1 std; 2 for median and 25-75 quartiles
%
% OUT
%
% var_mm(1,12)     : Monthly mean / median
% var_mlo(1,12)    : Monthly mean - 1std / 25 quartile
% var_mhi(1,12)    : Monthly mean + 1std / 75 quartile
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Sep 2016, stinky Paris)
%
%=========================================================================================================

var_mm  = zeros(1,12);
var_mlo = zeros(1,12);
var_mhi = zeros(1,12);
N_mm = zeros(1,12);

if ( i_type == 1 )
   for i = 1:12
      zaddr = find(month==i);
      N_mm(i) = size(zaddr,2);
      zarray = var1d(find(month==i));
      var_mm(i) = nanmean(zarray);
      zstd      = nanstd(zarray);
      var_mlo(i) = var_mm(i) - zstd;
      var_mhi(i) = var_mm(i) - zstd;
   end
elseif (i_type == 2)
    for i=1:12
       zaddr = find(month==i);
       N_mm(i) = size(zaddr,2);
       zarray = var1d(find(month==i));
       var_mm(i) = nanmedian(zarray);
       var_mlo(i) = quantile(zarray,0.25);
       var_mhi(i) = quantile(zarray,0.75);
    end 
end    