function [Cruise, Date, lat, lon, CoreID, diameter, hi, hs, fb, Nr]=bepsii_read_general(dir_list)

%=========================================================================================================
%
% bepsii_read_general
%
% IN
% dir_list : input directory
%
% OUT
% Cruise(Nr)   : cruise name
% Date(Nr)     : date (yyyymmdd)
% lat(Nr)      : latitude
% lon(Nr)      : longitude
% CoreID(Nr)   : core ID
% diameter(Nr) : core diameter
% hi(Nr)       : ice thickness
% hs(Nr)       : snow depth
% fb(Nr)       : freeboard
% Nr           : number of records found
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Aug 2015, Brussels)
%
%=========================================================================================================

disp ({' * bepsii_read_general : Read Scalars in', dir_list})
i_system={'MAC'} % or {'PC'}

% Number of Records in the directory
file_list = ls(dir_list);

if isequal(i_system,{'MAC'})
    Filename = strsplit(file_list);
    Nr = size(Filename,2) - 1;
end

if isequal(i_system,{'PC'})
    zFilename = cellstr(file_list);
    Nr = size(zFilename,1) - 2;  
    Filename(1:Nr) = zFilename(3:Nr+2);
end

% Declare variables
Cruise = cell(1,Nr);
Date   = zeros(1,Nr);
lat    = zeros(1,Nr);
lon    = zeros(1,Nr);
CoreID = cell(1,Nr);
dia    = zeros(1,Nr);
hi     = zeros(1,Nr);
hs     = zeros(1,Nr);
fb     = zeros(1,Nr);

disp ({' ** ... Start reading LOOP (takes time)...'})
    
for i=1:Nr
   i
   Percent_Complete=(i/Nr)*100
   zfile = [dir_list,'/',char(Filename(i))] % full path of the file
   
   % Read Cruise name
   [x,zCruise]=xlsread(zfile,1,'D1');
   if isempty(zCruise)==1
      Cruise(i)=NaN;
   else
      Cruise(i) = cellstr(zCruise);
   end
   
   % Read Date
   zaddr='D3';
   zDate=xlsread(zfile,1,zaddr);
   
   if isempty(zDate)==1
      Date(i)=NaN;
   else
      Date(i)=zDate;
   end

   % Read Station Latitude
   zaddr='D4';
   zlat=xlsread(zfile,1,zaddr);
   if isempty(zlat)==1
      lat(i)=NaN;
   else
      lat(i)=zlat;
   end
   
   % Read Station Longitude
   zaddr='D5';
   zlon=xlsread(zfile,1,zaddr);
   if isempty(zlon)==1
      lon(i)=NaN;
   else
      lon(i)=zlon;
   end
   
   % Read Ice core ID
   zaddr='D6';
   [x, zCoreID]=xlsread(zfile,1,zaddr);
   if isempty(zCoreID)==1;
      CoreID(i)=Filename(i);
   else
      CoreID(i)=cellstr(zCoreID);
   end
   
   % Read core diameter (who cares about core diameter)
   diameter(i)=NaN;
   
   % Read Ice thickness
   zaddr='D9';
   zhi=xlsread(zfile,1,zaddr);
   if isempty(zhi)==1
      hi(i)=NaN;
   else
      hi(i)=zhi;
   end
   
   % Read snow thickness
   zaddr='D10';
   zhs=xlsread(zfile,1,zaddr);
   if isempty(zhs)==1
      hs(i)=NaN;
   else
      hs(i)=zhs;
   end
   
   % Read Freeboard
   zaddr='D11';
   zfb=xlsread(zfile,1,zaddr);
   if isempty(zfb)==1
      fb(i)=NaN;
   else
      fb(i)=zfb;
   end

end